@@ -3,12 +3,14 @@ import pika
 import pika.exceptions
 import time
 import os
-
+import logging
 RABBIT_USER = os.getenv('RABBIT_USER') or 'admin'
 RABBIT_PASSWORD = os.getenv('RABBIT_PASSWORD') or 'admin'
 RABBIT_HOST = os.getenv('RABBIT_HOST') or '10.1.0.5'
 RABBIT_PORT = os.getenv('RABBIT_PORT') or '5672'
 
+logging.basicConfig(level=logging.WARNING, format='%(asctime)s - %(levelname)s - %(message)s', datefmt='%d-%b-%y %H:%M:%S')
+
 class consumer_class(): 
 
 
@@ -54,7 +56,7 @@ class consumer_class():
             return
 
         try:
-            self.handler(str(message))
+            # self.handler(str(message))
             print("publishing at : ", self.successful_job_routing_key)
             channel.basic_publish(exchange=self.exchange_name, routing_key=self.successful_job_routing_key, body=json.dumps(message))
         except Exception as err:
@@ -68,4 +70,6 @@ class consumer_class():
     def start_consume(self):
         self._channel.queue_bind(exchange=self.exchange_name, queue=self.qeue_name, routing_key=self.new_jobs_routing_key)
         self._channel.basic_consume(self.qeue_name, self.handle_new_message)
-        self._channel.start_consuming()
\ No newline at end of file
+        self._channel.start_consuming()
+
+
